Documentation
¶
Overview ¶
Package reply represents responses to messages of the messagebus
Index ¶
Constants ¶
const ( // TypeCommon - two binary fields: data and results. TypeCommon = core.ReplyType(iota) // TypeCode is code from storage. TypeCode // TypeClass is class from storage. TypeClass // TypeObject is object from storage. TypeObject // TypeDelegate is delegate reference from storage. TypeDelegate // TypeReference is common reply for methods returning reference to created records. TypeReference )
Variables ¶
This section is empty.
Functions ¶
func Deserialize ¶
Deserialize returns decoded reply.
Types ¶
type Code ¶
type Code struct {
Code []byte
MachineType core.MachineType
}
Code is code from storage.
Click to show internal directories.
Click to hide internal directories.