eventbus

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 25, 2018 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Overview

Package eventbus routes messages (contract calls & responses) and delivers'em to relevant modules.

Usage:

TODO:

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type EventBus

type EventBus struct {
	// contains filtered or unexported fields
}

EventBus is component that routes application logic requests, e.g. glue between network and logic runner

func New

New is a `EventBus` constructor, takes an executor object that satisfies LogicRunner interface

func (*EventBus) Dispatch

func (eb *EventBus) Dispatch(event core.Event) (core.Reaction, error)

Dispatch an `Event` and get a `Reaction` or error from remote host.

func (*EventBus) DispatchAsync

func (eb *EventBus) DispatchAsync(event core.Event)

DispatchAsync dispatches a `Event` to remote host.

func (*EventBus) Start

func (eb *EventBus) Start(c core.Components) error

func (*EventBus) Stop

func (eb *EventBus) Stop() error

Directories

Path Synopsis
Package event represents event that eventbus can route
Package event represents event that eventbus can route
Package reaction represents responses to messages of the eventbus
Package reaction represents responses to messages of the eventbus

Jump to