Documentation
¶
Overview ¶
Package jetdrop represents Jet Drops (Blocks) of a blockchain.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type JetDrop ¶
type JetDrop struct {
// Pulse number (probably we should save it too).
Pulse core.PulseNumber
// PrevHash is a hash of all record hashes belongs to previous pulse.
PrevHash []byte
// Hash is a hash of all record hashes belongs to one pulse.
Hash []byte
}
JetDrop is a blockchain block. It contains hashes of the current block and the previous one.
Click to show internal directories.
Click to hide internal directories.