Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ProxyHelper ¶
type ProxyHelper interface {
RouteCall(ref core.RecordRef, wait bool, method string, args []byte) ([]byte, error)
SaveAsChild(parentRef, classRef core.RecordRef, constructorName string, argsSerialized []byte) (core.RecordRef, error)
GetObjChildren(head core.RecordRef, class core.RecordRef) ([]core.RecordRef, error)
SaveAsDelegate(parentRef, classRef core.RecordRef, constructorName string, argsSerialized []byte) (core.RecordRef, error)
GetDelegate(object, ofType core.RecordRef) (core.RecordRef, error)
DeactivateObject(object core.RecordRef) error
Serialize(what interface{}, to *[]byte) error
Deserialize(from []byte, into interface{}) error
MakeErrorSerializable(error) error
}
ProxyHelper interface with methods that are needed by contract proxies
var Current ProxyHelper
Current - hackish way to give proxies access to the current environment
Click to show internal directories.
Click to hide internal directories.