Documentation
¶
Index ¶
- type ChildIterator
- type DownCallConstructorReq
- type DownCallConstructorResp
- type DownCallMethodReq
- type DownCallMethodResp
- type UpBaseReq
- type UpDeactivateObjectReq
- type UpDeactivateObjectResp
- type UpGetCodeReq
- type UpGetCodeResp
- type UpGetDelegateReq
- type UpGetDelegateResp
- type UpGetObjChildrenIteratorReq
- type UpGetObjChildrenIteratorResp
- type UpRespIface
- type UpRouteReq
- type UpRouteResp
- type UpSaveAsChildReq
- type UpSaveAsChildResp
- type UpSaveAsDelegateReq
- type UpSaveAsDelegateResp
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChildIterator ¶ added in v0.7.5
ChildIterator hold an iterator data of GetObjChildrenIterator method
type DownCallConstructorReq ¶ added in v0.0.5
type DownCallConstructorReq struct {
Code core.RecordRef
Name string
Arguments core.Arguments
Context *core.LogicCallContext
}
DownCallConstructorReq is a set of arguments for CallConstructor RPC in the runner
type DownCallConstructorResp ¶ added in v0.0.5
DownCallConstructorResp is response from CallConstructor RPC in the runner
type DownCallMethodReq ¶ added in v0.0.5
type DownCallMethodReq struct {
Context *core.LogicCallContext
Code core.RecordRef
Data []byte
Method string
Arguments core.Arguments
}
DownCallMethodReq is a set of arguments for CallMethod RPC in the runner
type DownCallMethodResp ¶ added in v0.0.5
DownCallMethodResp is response from CallMethod RPC in the runner
type UpBaseReq ¶ added in v0.4.0
type UpBaseReq struct {
Mode string
Callee core.RecordRef
Prototype core.RecordRef
Request core.RecordRef
}
UpBaseReq is a base type for all insgorund -> logicrunner requests
type UpDeactivateObjectReq ¶ added in v0.6.0
type UpDeactivateObjectReq struct {
UpBaseReq
}
UpDeactivateObjectReq is a set of arguments for DeactivateObject RPC in goplugin
type UpDeactivateObjectResp ¶ added in v0.6.0
type UpDeactivateObjectResp struct {
}
UpDeactivateObjectResp is response from DeactivateObject RPC in goplugin
type UpGetCodeReq ¶ added in v0.0.6
type UpGetCodeReq struct {
UpBaseReq
MType core.MachineType
Code core.RecordRef
}
UpGetCodeReq is a set of arguments for GetCode RPC in goplugin
type UpGetCodeResp ¶ added in v0.0.6
type UpGetCodeResp struct {
Code []byte
}
UpGetCodeResp is response from GetCode RPC in goplugin
type UpGetDelegateReq ¶ added in v0.2.0
UpGetDelegateReq is a set of arguments for GetDelegate RPC in goplugin
type UpGetDelegateResp ¶ added in v0.2.0
UpGetDelegateResp is response from GetDelegate RPC in goplugin
type UpGetObjChildrenIteratorReq ¶ added in v0.7.5
type UpGetObjChildrenIteratorReq struct {
UpBaseReq
IteratorID string
Obj core.RecordRef
Prototype core.RecordRef
}
UpGetObjChildrenIteratorReq is a set of arguments for GetObjChildrenIterator RPC in goplugin
type UpGetObjChildrenIteratorResp ¶ added in v0.7.5
type UpGetObjChildrenIteratorResp struct {
Iterator ChildIterator
}
UpGetObjChildrenIteratorResp is response from GetObjChildren RPC in goplugin
type UpRespIface ¶ added in v0.4.0
type UpRespIface interface{}
UpRespIface interface for UpBaseReq descendant responses
type UpRouteReq ¶
type UpRouteReq struct {
UpBaseReq
Wait bool
Object core.RecordRef
Method string
Arguments core.Arguments
ProxyPrototype core.RecordRef
}
UpRouteReq is a set of arguments for Send RPC in goplugin
type UpRouteResp ¶
UpRouteResp is response from Send RPC in goplugin
type UpSaveAsChildReq ¶ added in v0.0.6
type UpSaveAsChildReq struct {
UpBaseReq
Parent core.RecordRef
Prototype core.RecordRef
ConstructorName string
ArgsSerialized []byte
}
UpSaveAsChildReq is a set of arguments for SaveAsChild RPC in goplugin
type UpSaveAsChildResp ¶ added in v0.0.6
UpSaveAsChildResp is a set of arguments for SaveAsChild RPC in goplugin
type UpSaveAsDelegateReq ¶ added in v0.0.6
type UpSaveAsDelegateReq struct {
UpBaseReq
Into core.RecordRef
Prototype core.RecordRef
ConstructorName string
ArgsSerialized []byte
}
UpSaveAsDelegateReq is a set of arguments for SaveAsDelegate RPC in goplugin
type UpSaveAsDelegateResp ¶ added in v0.0.6
UpSaveAsDelegateResp is response from SaveAsDelegate RPC in goplugin