Documentation
¶
Overview ¶
Package message represents message that messagerouter can route
Index ¶
Constants ¶
const ( CallMethodMessageType // CallMethodMessage - Simply call method and return result CallConstructorMessageType // CallConstructorMessage is a message for calling constructor and obtain its response DelegateMessageType // DelegateMessage is a message for injecting a delegate )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type CallConstructorMessage ¶
type CallConstructorMessage struct {
ClassRef core.RecordRef
Name string
Arguments core.Arguments
// contains filtered or unexported fields
}
CallConstructorMessage is a message for calling constructor and obtain its response
func (*CallConstructorMessage) GetReference ¶
func (m *CallConstructorMessage) GetReference() core.RecordRef
GetReference implements core.Message
type CallMethodMessage ¶
type CallMethodMessage struct {
ObjectRef core.RecordRef
Request core.RecordRef
Method string
Arguments core.Arguments
// contains filtered or unexported fields
}
CallMethodMessage - Simply call method and return result
func (*CallMethodMessage) GetReference ¶
func (m *CallMethodMessage) GetReference() core.RecordRef
GetReference implements core.Message
type DelegateMessage ¶
type DelegateMessage struct {
Into core.RecordRef
Class core.RecordRef
Body []byte
// contains filtered or unexported fields
}
DelegateMessage is a message for saving contract's body as a delegate
func (*DelegateMessage) GetReference ¶
func (m *DelegateMessage) GetReference() core.RecordRef
GetReference implements core.Message
Click to show internal directories.
Click to hide internal directories.