Documentation
¶
Overview ¶
Package host is a fundamental part of networking system. Each host has:
- one real network address (IP or any other transport protocol address)
- multiple abstract network IDs (either host's own or ones belonging to relayed hosts)
Contains structures to describe network entities in code.
Usage:
originAddress, err := host.NewAddress(address)
if err != nil {
...
}
origin, err := host.NewOrigin(nil, originAddress)
if err != nil {
...
}
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Host ¶
type Host struct {
// NodeID is unique identifier of the node
NodeID core.RecordRef
// ShortID is shortened unique identifier of the node inside the globe
ShortID core.ShortNodeID
// Address is IP and port.
Address *Address
}
Host is the over-the-wire representation of a host.
func NewHostN ¶ added in v0.6.3
NewHostN creates a new Host with specified physical address and NodeID.
func NewHostNS ¶ added in v0.6.3
NewHostNS creates a new Host with specified physical address, NodeID and ShortID.
Click to show internal directories.
Click to hide internal directories.