Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type NodeKeeper ¶
type NodeKeeper interface {
// GetActiveNodes get active nodes.
GetActiveNodes() []*core.ActiveNode
// GetUnsyncHash get hash computed based on the list of unsync nodes, and the size of this list.
GetUnsyncHash() (hash []byte, unsyncCount int)
// GetUnsync gets the local unsync list (excluding other nodes unsync lists)
GetUnsync() []*core.ActiveNode
// Sync initiate transferring unsync -> sync, sync -> active. If approved is false, unsync is not transferred to sync
Sync(approved bool)
// AddUnsync add unsync node to the local unsync list
AddUnsync(*core.ActiveNode)
// AddUnsyncGossip merge unsync list from another node to the local unsync list
AddUnsyncGossip([]*core.ActiveNode)
}
Click to show internal directories.
Click to hide internal directories.